ApiUrls class

API Url constants

Constructors

ApiUrls()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

chatHistory(String email) String
chatMessages(String chatId) String
faq(String businessId) → dynamic
sendDeviceToken(dynamic ticketId) String
sendImage(String businessId) String
ticketStatus(String ticketId) String
updateTicketStatus(String ticketId) String

Constants

initChat → const String
sendChat → const String
socketURL → const String