EnifApi class

Constructors

EnifApi()

Properties

baseUrl String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getChatHistory(String email, String businessId) → ApiRequest<List<ChatSession>, ChatSession>
getChatMessages(String email, String businessId, String chatId) → ApiRequest<List<Message>, Message>
getFaqs(String businessId) → ApiRequest<List<Faq>, Faq>
initChat(InitChatDto body) → ApiRequest<ChatSession, ChatSession>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendChat(SendChatDto body) → ApiRequest<SendChatModel, SendChatModel>
sendDeviceToken(SendDeviceTokenDto body, dynamic ticketId) → ApiRequest<SendDeviceTokenModel, SendDeviceTokenModel>
sendImage(SendImageDto body, String businessId) → ApiRequest<List<String>, String>
ticketStatus(String ticketId) → ApiRequest<bool, bool>
toString() String
A string representation of this object.
inherited
updateTicketStatus(String ticketId) → ApiRequest<bool, bool>
uploadImages(List<String> imagePaths, String businessId) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited