FaqRepository class

Inheritance
  • Object
  • DataRepository
  • FaqRepository

Constructors

FaqRepository()

Properties

defaultErrorMessage String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
localRepository → LocalRepository
finalinherited
remoteRepository → RemoteRepository
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatErrorMessage<E>(dynamic error, String defaultErrorMessage) → ApiError
inherited
getFaqs(bool forceCache) Future<ApiResponse<List<Faq>, Faq>>
handleRequest<ResultType, Item>(ApiRequest<ResultType, Item> request, {CacheDescription? cache, int timeout = 50, bool retryWithCache = false, bool retry = false}) Future<ApiResponse<ResultType, Item>>
manages fetching data, decides where to fetch data from
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldUseCache(LocalRepository repository, CacheDescription? cache) Future<bool>
inherited
toString() String
A string representation of this object.
inherited
validateData<ResultType, Item>(ApiResponse<ResultType, Item> response) → ResultType?
validate data to be saved to cache is not an empty list
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited